@@ -256,7 +256,7 @@ static apr_status_t ajp_marshal_into_msgb(ajp_msg_t *msg,
 
         ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r, APLOGNO(00968)
                "ajp_marshal_into_msgb: "
-               "Error appending the message begining");
+               "Error appending the message beginning");
         return APR_EGENERAL;
     }
 
